@@ -54,4 +54,49 @@ enum Marker {
 #[test]
 fn test_marker() {
     validate::<Marker>(1 + 3 + 1 + 3);
+}
+
+#[derive(Finite, PartialEq, Eq, PartialOrd, Ord, Clone, Copy)]
+enum General {
+    Specific(Specific),
+    C,
+    D
+}
+
+#[derive(Finite, PartialEq, Eq, PartialOrd, Ord, Clone, Copy)]
+enum Specific {
+    A,
+    B
+}
+
+#[test]
+fn test_general() {
+    validate::<General>(2 + 2);
+}
+
+#[derive(Finite, PartialEq, Eq, PartialOrd, Ord, Clone, Copy)]
+struct Unit;
+
+#[test]
+fn test_unit() {
+    validate::<Unit>(1);
+}
+
+#[derive(Finite, PartialEq, Eq, PartialOrd, Ord, Clone, Copy)]
+struct ColorTriple(Color, Color, Color);
+
+#[test]
+fn test_color_triple() {
+    validate::<ColorTriple>(3 * 3 * 3);
+}
+
+#[derive(Finite, PartialEq, Eq, PartialOrd, Ord, Clone, Copy)]
+struct Options {
+    pub color: Color,
+    general: General
+}
+
+#[test]
+fn test_options() {
+    validate::<Options>(3 * (2 + 2));
 }
\ No newline at end of file
